# hhpy - Data Science convenience project


Built with [Python Package Template Project](https://github.com/AlexIoannides/py-package-template/). 

My attempt at creating a convenient way to use different data science and machine learning operations and frameworks using one unified way.
The main idea is to store data in pandas DataFrames and start from there.

Also provides several extensions on pandas, matplotlib and seaborn for convenience.

## Installing

Install and update using [pip](https://pypi.org/project/hhpy/):

```bash
pip install hhpy
```

Or get the latest dev version from github

```bash
pip install git+https://github.com/rhedak/hhpy
```

## Documentation

Documentation is available at [https://hhpy.readthedocs.io/](https://hhpy.readthedocs.io/)